@@ -40,9 +40,9 @@ copyright = '2008, Ian Bicking'
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '1.7.3'
+version = '1.7'
 # The full version, including alpha/beta/rc tags.
-release = '1.7.3'
+release = '1.7.4.2'
 
 # There are two options for replacing |today|: either, you set today to some
 # non-false value, then it is used:
